Learn R Programming

MOCHA (version 1.1.0)

filterCoAccessibleLinks: filterCoAccessibleLinks

Description

filterCoAccessibleLinks will filter the output from getCoAccessibleLinks by a threshold, retaining links with a absolute correlation greater than the threshold. This function also adds the chr, start, and end site of each link to the output table.

Usage

filterCoAccessibleLinks(TileCorr, threshold = 0.5)

Value

FilteredTileCorr The filtered correlation table with chr, start, and end site of each link

Arguments

TileCorr

The correlation table output from getCoAccessibleLinks

threshold

Keep

Examples

Run this code
if (FALSE) {
# links is the output of MOCHA::getCoAccessibleLinks
MOCHA::filterCoAccessibleLinks(links, threshold = 0.5)
}

Run the code above in your browser using DataLab