Learn R Programming

MOCHA (version 1.1.0)

packMOCHA: packMOCHA

Description

packMOCHA combines a MOCHA object (Sample-Tile Matrix or tileResults) with its saved coverage tracks into a single zip archive. This allows MOCHA objects and the necessary coverage files for plotting to be shared to other file systems. See also: unpackMOCHA

Usage

packMOCHA(MOCHAObj, zipfile, verbose = FALSE)

Value

zipfile Path to zip archive.

Arguments

MOCHAObj

A MultiAssayExperiment or RangedSummarizedExperiment, from MOCHA

zipfile

Filename and path of the zip archive.

verbose

Set TRUE to display additional messages. Default is FALSE.

Examples

Run this code
if (FALSE) {
# Depends on and manipulates files on filesystem
myOutputDir <- "/home/documents/MOCHA_out"
zipPath <- MOCHA::packMOCHA(
  tileResults, zipfile = file.path(myOutputDir, "testzip.zip")
)
}

Run the code above in your browser using DataLab