Learn R Programming

MOCHA (version 1.1.0)

unpackMOCHA: unpackMOCHA

Description

unpackMOCHA will unpack a zip archive created by unpackMOCHA, setting the stored MOCHA object's stored directory path to the new location. See also: packMOCHA

Usage

unpackMOCHA(zipfile, exdir, verbose = FALSE)

Value

MOCHAObj the MOCHA object (tileResults or Sample-Tile Matrix)

Arguments

zipfile

Filepath to the packed MOCHA object.

exdir

The path to the external directory where you want to unpack the MOCHA object.

verbose

Display additional messages. Default is FALSE.

Examples

Run this code
if (FALSE) {
# Depends on files existing on your system
MOCHA::unpackMOCHA(zipfile = "./mochaobj.zip", exdir = "./newMOCHAdir")
}

Run the code above in your browser using DataLab